from bot_core.logging.database_logger import DatabaseLogger
from bot_data.abc.migration_abc import MigrationABC
from bot_data.db_context import DBContext


class ScheduledEventMigration(MigrationABC):
    name = "1.2.0_ScheduledEventMigration"

    def __init__(self, logger: DatabaseLogger, db: DBContext):
        MigrationABC.__init__(self)
        self._logger = logger
        self._db = db
        self._cursor = db.cursor

    def upgrade(self):
        self._logger.debug(__name__, "Running upgrade")

        self._cursor.execute(
            str(
                f"""
                    CREATE TABLE IF NOT EXISTS `ScheduledEvents` (
                        `Id` BIGINT NOT NULL AUTO_INCREMENT,
                        `Interval` VARCHAR(255) NOT NULL,
                        `Name` VARCHAR(255) NOT NULL,
                        `Description` VARCHAR(255) NOT NULL,
                        `ChannelId` BIGINT NULL,
                        `StartTime` DATETIME(6) NOT NULL,
                        `EndTime` DATETIME(6) NULL,
                        `EntityType` ENUM(1,2,3) NOT NULL,
                        `Location` VARCHAR(255) NULL,
                        `ServerId` BIGINT,
                        `CreatedAt` DATETIME(6) NULL DEFAULT CURRENT_TIMESTAMP(6),
                        `LastModifiedAt` DATETIME(6) NULL DEFAULT CURRENT_TIMESTAMP(6) ON UPDATE CURRENT_TIMESTAMP(6),
                        PRIMARY KEY(`Id`),
                        FOREIGN KEY (`ServerId`) REFERENCES `Servers`(`ServerId`)
                    );
                """
            )
        )

        self._exec(__file__, "scheduled_events.sql")

    def downgrade(self):
        self._cursor.execute("DROP TABLE `ShortRoleNames`;")
        self._cursor.execute("DROP TABLE `ShortRoleNamesHistory`;")
